@@ -1,9 +1,15 @@
 import click
 
-from gevault.lib.admin import Admin
-from gevault.lib.refresh import Refresh
-from gevault.lib.users import Users
-from gevault.lib.tester import Test
+try:
+    from gevault.lib.admin import Admin
+    from gevault.lib.refresh import Refresh
+    from gevault.lib.users import Users
+    from gevault.lib.tester import Test
+except ModuleNotFoundError:
+    from lib.admin import Admin
+    from lib.refresh import Refresh
+    from lib.users import Users
+    from lib.tester import Test    
 
 @click.group()
 def main():
