@@ -2,8 +2,10 @@ import json
 from os.path import expanduser
 
 from hvac.exceptions import InvalidRequest
-
-from gevault.lib.vault import Vault
+try:
+    from gevault.lib.vault import Vault
+except ModuleNotFoundError:
+    from lib.vault import Vault
 
 MOUNT_POINT = 'ssh-client-signer'
 SIGNING_ROLE = "vault-signing-role"
